@@ -12,7 +12,7 @@ guiqwt.io
 ---------
 
 The `io` module provides input/output helper functions:
-    * :py:func:`guiqwt.io.imread`: load an image (.png, .tiff, 
+    * :py:func:`guiqwt.io.imread`: load an image (.png, .tiff,
       .dicom, etc.) and return its data as a NumPy array
     * :py:func:`guiqwt.io.imwrite`: save an array to an image file
     * :py:func:`guiqwt.io.load_items`: load plot items from HDF5
@@ -27,22 +27,19 @@ Reference
 .. autofunction:: save_items
 """
 
-from __future__ import print_function
 
 import sys
 import re
 import os.path as osp
 import numpy as np
 
-from qtpy.py3compat import is_text_string, to_text_string
-
 # Local imports
 from guiqwt.config import _
 
 
 def scale_data_to_dtype(data, dtype):
     """Scale array `data` to fit datatype `dtype` dynamic range
-    
+
     WARNING: modifies data in place"""
     info = np.iinfo(dtype)
     dmin = data.min()
@@ -67,11 +64,11 @@ def eliminate_outliers(data, percent=2.0, bins=256):
 # ===============================================================================
 class FileType(object):
     """Filetype object:
-        * `name` : description of filetype,
-        * `read_func`, `write_func` : I/O callbacks,
-        * `extensions`: filename extensions (with a dot!) or filenames,
-        (list, tuple or space-separated string)
-        * `data_types`: supported data types"""
+    * `name` : description of filetype,
+    * `read_func`, `write_func` : I/O callbacks,
+    * `extensions`: filename extensions (with a dot!) or filenames,
+    (list, tuple or space-separated string)
+    * `data_types`: supported data types"""
 
     def __init__(
         self,
@@ -83,7 +80,7 @@ class FileType(object):
         requires_template=False,
     ):
         self.name = name
-        if is_text_string(extensions):
+        if isinstance(extensions, str):
             extensions = extensions.split()
         self.extensions = [osp.splitext(" " + ext)[1] for ext in extensions]
         self.read_func = read_func
@@ -130,7 +127,7 @@ class ImageIOHandler(object):
 
     def get_filters(self, action, dtype=None, template=None):
         """Return file type filters for `action` (string: 'save' or 'load'),
-        `dtype` data type (None: all data types), and `template` (True if save 
+        `dtype` data type (None: all data types), and `template` (True if save
         function requires a template (e.g. DICOM files), False otherwise)"""
         filters = self.allfilters(action, dtype, template)
         for ftype in self.filetypes:
@@ -195,19 +192,23 @@ iohandler = ImageIOHandler()
 # tifffile-based Private I/O functions
 # ==============================================================================
 
+
 def _imread_tiff(filename):
     """Open a TIFF image and return a NumPy array"""
     try:
         import tifffile
+
         return tifffile.imread(filename)
     except ImportError:
         return _imread_pil(filename)
 
+
 def _imwrite_tiff(filename, arr):
     """Save a NumPy array to a TIFF file"""
     try:
         import tifffile
-        return tifffile.imread(filename, arr)
+
+        return tifffile.imwrite(filename, arr)
     except ImportError:
         return _imwrite_pil(filename, arr)
 
@@ -458,13 +459,11 @@ iohandler.add(
 # ==============================================================================
 def imread(fname, ext=None, to_grayscale=False):
     """Return a NumPy array from an image filename `fname`.
-    
+
     If `to_grayscale` is True, convert RGB images to grayscale
     The `ext` (optional) argument is a string that specifies the file extension
-    which defines the input format: when not specified, the input format is 
+    which defines the input format: when not specified, the input format is
     guessed from filename."""
-    if not is_text_string(fname):
-        fname = to_text_string(fname)  # in case filename is a QString instance
     if ext is None:
         _base, ext = osp.splitext(fname)
     arr = iohandler.get_readfunc(ext)(fname)
@@ -477,16 +476,14 @@ def imread(fname, ext=None, to_grayscale=False):
 
 def imwrite(fname, arr, ext=None, dtype=None, max_range=None, **kwargs):
     """Save a NumPy array to an image filename `fname`.
-    
+
     If `to_grayscale` is True, convert RGB images to grayscale
     The `ext` (optional) argument is a string that specifies the file extension
-    which defines the input format: when not specified, the input format is 
+    which defines the input format: when not specified, the input format is
     guessed from filename.
-    If `max_range` is True, array data is scaled to fit the `dtype` (or data 
+    If `max_range` is True, array data is scaled to fit the `dtype` (or data
     type itself if `dtype` is None) dynamic range
     Warning: option `max_range` changes data in place"""
-    if not is_text_string(fname):
-        fname = to_text_string(fname)  # in case filename is a QString instance
     if ext is None:
         _base, ext = osp.splitext(fname)
     if max_range:
@@ -621,8 +618,8 @@ def load_item(reader, group_name):
 
 def save_items(writer, items):
     """Save items to HDF5 file:
-        * writer: :py:class:`guidata.hdf5io.HDF5Writer` object
-        * items: serializable plot items"""
+    * writer: :py:class:`guidata.hdf5io.HDF5Writer` object
+    * items: serializable plot items"""
     counts = {}
     names = []
 
@@ -642,14 +639,16 @@ def save_items(writer, items):
 
 def load_items(reader):
     """Load items from HDF5 file:
-        * reader: :py:class:`guidata.hdf5io.HDF5Reader` object"""
+    * reader: :py:class:`guidata.hdf5io.HDF5Reader` object"""
     with reader.group("plot_items"):
         names = reader.read_sequence()
     items = []
     for name in names:
-        klass_name = re.match(
-            r"([A-Z]+[A-Za-z0-9\_]*)\_([0-9]*)", name.decode()
-        ).groups()[0]
+        try:
+            name_str = name.decode()
+        except AttributeError:
+            name_str = name
+        klass_name = re.match(r"([A-Z]+[A-Za-z0-9\_]*)\_([0-9]*)", name_str).groups()[0]
         klass = item_class_from_name(klass_name)
         item = klass()
         with reader.group(name):
@@ -662,4 +661,3 @@ if __name__ == "__main__":
     # Test if items can all be constructed from their Python module
     for name in SERIALIZABLE_ITEMS:
         print(name, "-->", item_class_from_name(name))
-
