@@ -19,8 +19,8 @@ The `labels` module provides plot items related to labels and legends:
     * :py:class:`guiqwt.shapes.RangeComputation2d`
     * :py:class:`guiqwt.shapes.DataInfoLabel`
 
-A label or a legend is a plot item (derived from QwtPlotItem) that may be 
-displayed on a 2D plotting widget like :py:class:`guiqwt.curve.CurvePlot` 
+A label or a legend is a plot item (derived from QwtPlotItem) that may be
+displayed on a 2D plotting widget like :py:class:`guiqwt.curve.CurvePlot`
 or :py:class:`guiqwt.image.ImagePlot`.
 
 Reference
@@ -50,7 +50,6 @@ from qtpy.QtGui import QPen, QColor, QTextDocument
 from qtpy.QtCore import QRectF, QPointF
 
 from guidata.utils import assert_interfaces_valid, update_dataset
-from qtpy.py3compat import to_text_string
 
 # Local imports
 from guiqwt.transitional import QwtPlotItem
@@ -323,7 +322,7 @@ class LabelItem(AbstractLabelItem):
         self.labelparam.xg, self.labelparam.yg = x, y
 
     def get_plain_text(self):
-        return to_text_string(self.text.toPlainText())
+        return self.text.toPlainText()
 
     def set_text(self, text=None):
         if text is not None:
@@ -505,15 +504,15 @@ class ObjectInfo(object):
 
 class RangeInfo(ObjectInfo):
     """ObjectInfo handling XRangeSelection shape informations: x, dx
-    
+
     label: formatted string
     xrangeselection: XRangeSelection object
-    function: input arguments are x, dx ; returns objects used to format the 
+    function: input arguments are x, dx ; returns objects used to format the
     label. Default function is `lambda x, dx: (x, dx)`.
 
     Example:
     -------
-    
+
     x = linspace(-10, 10, 10)
     y = sin(sin(sin(x)))
     xrangeselection = make.range(-2, 2)
@@ -523,7 +522,7 @@ class RangeInfo(ObjectInfo):
     """
 
     def __init__(self, label, xrangeselection, function=None):
-        self.label = to_text_string(label)
+        self.label = str(label)
         self.range = xrangeselection
         if function is None:
             function = lambda x, dx: (x, dx)
@@ -537,17 +536,17 @@ class RangeInfo(ObjectInfo):
 
 
 class RangeComputation(ObjectInfo):
-    """ObjectInfo showing curve computations relative to a XRangeSelection 
+    """ObjectInfo showing curve computations relative to a XRangeSelection
     shape.
-    
+
     label: formatted string
     curve: CurveItem object
     xrangeselection: XRangeSelection object
-    function: input arguments are x, y arrays (extraction of arrays 
+    function: input arguments are x, y arrays (extraction of arrays
     corresponding to the xrangeselection X-axis range)"""
 
     def __init__(self, label, curve, xrangeselection, function=None):
-        self.label = to_text_string(label)
+        self.label = str(label)
         self.curve = curve
         self.range = xrangeselection
         if function is None:
@@ -580,7 +579,7 @@ class RangeComputation(ObjectInfo):
 
 class RangeComputation2d(ObjectInfo):
     def __init__(self, label, image, rect, function):
-        self.label = to_text_string(label)
+        self.label = str(label)
         self.image = image
         self.rect = rect
         self.func = function
@@ -616,4 +615,3 @@ class DataInfoLabel(LabelItem):
         for info in self.infos:
             text.append(info.get_text())
         self.set_text("<br/>".join(text))
-
