@@ -11,18 +11,18 @@
 guiqwt.pyplot
 -------------
 
-The `pyplot` module provides an interactive plotting interface similar to 
+The `pyplot` module provides an interactive plotting interface similar to
 `Matplotlib`'s, i.e. with MATLAB-like syntax.
 
-The :py:mod:`guiqwt.pyplot` module was designed to be as close as possible 
-to the :py:mod:`matplotlib.pyplot` module, so that one could easily switch 
+The :py:mod:`guiqwt.pyplot` module was designed to be as close as possible
+to the :py:mod:`matplotlib.pyplot` module, so that one could easily switch
 between these two modules by simply changing the import statement. Basically,
-if `guiqwt` does support the plotting commands called in your script, replacing 
-``import matplotlib.pyplot`` by ``import guiqwt.pyplot`` should suffice, as 
+if `guiqwt` does support the plotting commands called in your script, replacing
+``import matplotlib.pyplot`` by ``import guiqwt.pyplot`` should suffice, as
 shown in the following example:
-    
+
     * Simple example using `matplotlib`::
-    
+
         import matplotlib.pyplot as plt
         import numpy as np
         x = np.linspace(-10, 10)
@@ -30,7 +30,7 @@ shown in the following example:
         plt.show()
 
     * Switching from `matplotlib` to `guiqwt` is trivial::
-    
+
         import guiqwt.pyplot as plt # only this line has changed!
         import numpy as np
         x = np.linspace(-10, 10)
@@ -100,7 +100,6 @@ Reference
 .. autofunction:: pcolor
 """
 
-from __future__ import print_function
 
 import sys
 from qtpy.QtWidgets import (
@@ -117,7 +116,7 @@ from qtpy import PYQT5
 
 import guidata
 from guidata.configtools import get_icon
-from qtpy.py3compat import is_text_string, to_text_string
+from guidata.qthelpers import win32_fix_title_bar_background
 
 # Local imports
 from guiqwt.config import _
@@ -138,6 +137,7 @@ _current_axes = None
 class Window(QMainWindow):
     def __init__(self, wintitle):
         super(Window, self).__init__()
+        win32_fix_title_bar_background(self)
         self.default_tool = None
         self.plots = []
         self.itemlist = PlotItemList(None)
@@ -165,7 +165,7 @@ class Window(QMainWindow):
 
     def closeEvent(self, event):
         global _figures, _current_fig, _current_axes
-        figure_title = to_text_string(self.windowTitle())
+        figure_title = str(self.windowTitle())
         if _figures.pop(figure_title) == _current_fig:
             _current_fig = None
             _current_axes = None
@@ -240,7 +240,7 @@ class Figure(object):
         self.win.display()
 
     def save(self, fname, format, draft):
-        if is_text_string(fname):
+        if isinstance(fname, str):
             if format == "pdf":
                 self.app = guidata.qapplication()
                 if draft:
@@ -411,7 +411,7 @@ def _make_figure_title(N=None):
     global _figures
     if N is None:
         N = len(_figures) + 1
-    if is_text_string(N):
+    if isinstance(N, str):
         return N
     else:
         return "Figure %d" % N
@@ -451,7 +451,7 @@ def gca():
 
 def show(mainloop=True):
     """
-    Show all figures and enter Qt event loop    
+    Show all figures and enter Qt event loop
     This should be the last line of your script
     """
     global _figures, _interactive
@@ -470,7 +470,7 @@ def _show_if_interactive():
 def subplot(n, m, k):
     """
     Create a subplot command
-    
+
     Example::
 
         import numpy as np
@@ -494,9 +494,9 @@ def subplot(n, m, k):
 def plot(*args, **kwargs):
     """
     Plot curves
-    
+
     Example::
-    
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         plot(x, np.sin(x), "r+")
@@ -516,9 +516,9 @@ def plot(*args, **kwargs):
 def plotyy(x1, y1, x2, y2):
     """
     Plot curves with two different y axes
-    
+
     Example::
-        
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         plotyy(x, np.sin(x), x, np.cos(x))
@@ -538,9 +538,9 @@ def plotyy(x1, y1, x2, y2):
 def hist(data, bins=None, logscale=None, title=None, color=None):
     """
     Plot 1-D histogram
-    
+
     Example::
-        
+
         from numpy.random import normal
         data = normal(0, 1, (2000, ))
         hist(data)
@@ -558,9 +558,9 @@ def hist(data, bins=None, logscale=None, title=None, color=None):
 def semilogx(*args, **kwargs):
     """
     Plot curves with logarithmic x-axis scale
-    
+
     Example::
-        
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         semilogx(x, np.sin(12*x), "g-")
@@ -577,9 +577,9 @@ def semilogx(*args, **kwargs):
 def semilogy(*args, **kwargs):
     """
     Plot curves with logarithmic y-axis scale
-    
+
     Example::
-        
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         semilogy(x, np.sin(12*x), "g-")
@@ -596,9 +596,9 @@ def semilogy(*args, **kwargs):
 def loglog(*args, **kwargs):
     """
     Plot curves with logarithmic x-axis and y-axis scales
-    
+
     Example::
-        
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         loglog(x, np.sin(12*x), "g-")
@@ -616,9 +616,9 @@ def loglog(*args, **kwargs):
 def errorbar(*args, **kwargs):
     """
     Plot curves with error bars
-    
+
     Example::
-        
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         errorbar(x, -1+x**2/20+.2*np.random.rand(len(x)), x/20)
@@ -642,9 +642,9 @@ def imshow(data, interpolation=None, mask=None):
     """
     Display the image in *data* to current axes
     interpolation: 'nearest', 'linear' (default), 'antialiasing'
-    
+
     Example::
-        
+
         import numpy as np
         x = np.linspace(-5, 5, 1000)
         img = np.fromfunction(lambda x, y: np.sin((x/200.)*(y/200.)**2), (1000, 1000))
@@ -679,9 +679,9 @@ def imshow(data, interpolation=None, mask=None):
 def pcolor(*args):
     """
     Create a pseudocolor plot of a 2-D array
-    
+
     Example::
-    
+
         import numpy as np
         r = np.linspace(1., 16, 100)
         th = np.linspace(0., np.pi, 100)
@@ -730,21 +730,21 @@ def title(text):
 
 def xlabel(bottom="", top=""):
     """Set current x-axis label"""
-    assert is_text_string(bottom) and is_text_string(top)
+    assert isinstance(bottom, str) and isinstance(top, str)
     axe = gca()
     axe.xlabel = (bottom, top)
 
 
 def ylabel(left="", right=""):
     """Set current y-axis label"""
-    assert is_text_string(left) and is_text_string(right)
+    assert isinstance(left, str) and isinstance(right, str)
     axe = gca()
     axe.ylabel = (left, right)
 
 
 def zlabel(label):
     """Set current z-axis label"""
-    assert is_text_string(label)
+    assert isinstance(label, str)
     axe = gca()
     axe.zlabel = label
 
@@ -752,10 +752,10 @@ def zlabel(label):
 def yreverse(reverse):
     """
     Set y-axis direction of increasing values
-    
+
     reverse = False (default)
         y-axis values increase from bottom to top
-    
+
     reverse = True
         y-axis values increase from top to bottom
     """
@@ -811,10 +811,10 @@ def close(N=None, all=False):
 def savefig(fname, format=None, draft=False):
     """
     Save figure
-    
+
     Currently supports PDF and PNG formats only
     """
-    if not is_text_string(fname) and format is None:
+    if not isinstance(fname, str) and format is None:
         # Buffer/fd
         format = "png"
     if format is None:
