@@ -19,8 +19,8 @@ The `shapes` module provides geometrical shapes:
     * :py:class:`guiqwt.shapes.Axes`
     * :py:class:`guiqwt.shapes.XRangeSelection`
 
-A shape is a plot item (derived from QwtPlotItem) that may be displayed 
-on a 2D plotting widget like :py:class:`guiqwt.curve.CurvePlot` 
+A shape is a plot item (derived from QwtPlotItem) that may be displayed
+on a 2D plotting widget like :py:class:`guiqwt.curve.CurvePlot`
 or :py:class:`guiqwt.image.ImagePlot`.
 
 .. seealso:: module :py:mod:`guiqwt.annotations`
@@ -29,19 +29,19 @@ Examples
 ~~~~~~~~
 
 A shape may be created:
-    * from the associated plot item class (e.g. `RectangleShape` to create a 
-      rectangle): the item properties are then assigned by creating the 
+    * from the associated plot item class (e.g. `RectangleShape` to create a
+      rectangle): the item properties are then assigned by creating the
       appropriate style parameters object
       (:py:class:`guiqwt.styles.ShapeParam`)
-      
+
 >>> from guiqwt.shapes import RectangleShape
 >>> from guiqwt.styles import ShapeParam
 >>> param = ShapeParam()
 >>> param.title = 'My rectangle'
 >>> rect_item = RectangleShape(0., 2., 4., 0., param)
-      
+
     * or using the `plot item builder` (see :py:func:`guiqwt.builder.make`):
-      
+
 >>> from guiqwt.builder import make
 >>> rect_item = make.rectangle(0., 2., 4., 0., title='My rectangle')
 
@@ -74,15 +74,15 @@ Reference
    :inherited-members:
 """
 
+import os
+import sys
 import numpy as np
 from math import fabs, sqrt, sin, cos, pi
 
 from qtpy.QtGui import QPen, QBrush, QPolygonF, QTransform, QPainter
 from qtpy.QtCore import Qt, QRectF, QPointF, QLineF
-from qtpy import PYSIDE2
 
 from guidata.utils import assert_interfaces_valid, update_dataset
-from qtpy.py3compat import maxsize
 
 # Local imports
 from guiqwt.transitional import QwtPlotItem, QwtSymbol, QwtPlotMarker
@@ -103,13 +103,15 @@ from guiqwt.geometry import (
 )
 from guiqwt.baseplot import canvas_to_axes
 
+QT_API = os.environ["QT_API"]
+
 
 class AbstractShape(QwtPlotItem):
     """Interface pour les objets manipulables
     il n'est pas nécessaire de dériver de QwtShape si on
     réutilise une autre classe dérivée de QwtPlotItem
-    
-    La classe de base 
+
+    La classe de base
     """
 
     __implements__ = (IBasePlotItem,)
@@ -192,7 +194,7 @@ class AbstractShape(QwtPlotItem):
         """
         Return a tuple with four elements:
         (distance, attach point, inside, other_object)
-        
+
         distance : distance in pixels (canvas coordinates)
                    to the closest attach point
         attach point: handle of the attach point
@@ -219,7 +221,7 @@ class AbstractShape(QwtPlotItem):
         """
         Change the appearance of this item according
         to the parameter set provided
-        
+
         params is a list of Datasets of the same types as those returned
         by get_item_parameters
         """
@@ -385,7 +387,7 @@ class Marker(QwtPlotMarker):
         """
         Return a tuple with four elements:
         (distance, attach point, inside, other_object)
-        
+
         distance : distance in pixels (canvas coordinates)
                    to the closest attach point
         attach point: handle of the attach point
@@ -426,7 +428,7 @@ class Marker(QwtPlotMarker):
         """
         Change the appearance of this item according
         to the parameter set provided
-        
+
         params is a list of Datasets of the same types as those returned
         by get_item_parameters
         """
@@ -684,7 +686,7 @@ class PolygonShape(AbstractShape):
         painter.setPen(pen)
         painter.setBrush(brush)
         points = self.transform_points(xMap, yMap)
-        if PYSIDE2:
+        if QT_API.startswith("pyside"):
             points = list(points)
         if self.ADDITIONNAL_POINTS:
             shape_points = points[: -self.ADDITIONNAL_POINTS]
@@ -706,7 +708,7 @@ class PolygonShape(AbstractShape):
 
     def poly_hit_test(self, plot, ax, ay, pos):
         pos = QPointF(pos)
-        dist = maxsize
+        dist = sys.maxsize
         handle = -1
         Cx, Cy = pos.x(), pos.y()
         poly = QPolygonF()
@@ -727,7 +729,7 @@ class PolygonShape(AbstractShape):
     def hit_test(self, pos):
         """return (dist, handle, inside)"""
         if not self.plot():
-            return maxsize, 0, False, None
+            return sys.maxsize, 0, False, None
         return self.poly_hit_test(self.plot(), self.xAxis(), self.yAxis(), pos)
 
     def add_local_point(self, pos):
@@ -812,7 +814,7 @@ class SegmentShape(PolygonShape):
 
     def set_rect(self, x1, y1, x2, y2):
         """
-        Set the start point of this segment to (x1, y1) 
+        Set the start point of this segment to (x1, y1)
         and the end point of this line to (x2, y2)
         """
         self.set_points([(x1, y1), (x2, y2), (0.5 * (x1 + x2), 0.5 * (y1 + y2))])
@@ -864,7 +866,7 @@ class RectangleShape(PolygonShape):
 
     def set_rect(self, x1, y1, x2, y2):
         """
-        Set the coordinates of the rectangle's top-left corner to (x1, y1), 
+        Set the coordinates of the rectangle's top-left corner to (x1, y1),
         and of its bottom-right corner to (x2, y2).
         """
         self.set_points([(x1, y1), (x2, y1), (x2, y2), (x1, y2)])
@@ -927,17 +929,17 @@ class ObliqueRectangleShape(PolygonShape):
     def set_rect(self, x0, y0, x1, y1, x2, y2, x3, y3):
         """
         Set the rectangle corners coordinates:
-            
+
             (x0, y0): top-left corner
             (x1, y1): top-right corner
             (x2, y2): bottom-right corner
             (x3, y3): bottom-left corner
-            
+
         ::
-            
+
             x: additionnal points (handles used for rotation -- other handles
             being used for rectangle resizing)
-            
+
             (x0, y0)------>(x1, y1)
                 ↑             |
                 |             |
@@ -1134,7 +1136,7 @@ class EllipseShape(PolygonShape):
     def hit_test(self, pos):
         """return (dist, handle, inside)"""
         if not self.plot():
-            return maxsize, 0, False, None
+            return sys.maxsize, 0, False, None
         dist, handle, inside, other = self.poly_hit_test(
             self.plot(), self.xAxis(), self.yAxis(), pos
         )
