@@ -7,24 +7,30 @@
 
 """Renders a cross section chosen by a cross marker"""
 
-SHOW = True # Show test in GUI-based test launcher
+SHOW = True  # Show test in GUI-based test launcher
 
 import os.path as osp, numpy as np
 
 from guiqwt.plot import ImageDialog
 from guiqwt.builder import make
 
+
 def create_window():
-    win = ImageDialog(edit=False, toolbar=True, wintitle="Cross sections test",
-                      options=dict(show_xsection=True, show_ysection=True,
-                                   show_itemlist=True))
+    win = ImageDialog(
+        edit=False,
+        toolbar=True,
+        wintitle="Cross sections test",
+        options=dict(show_xsection=True, show_ysection=True, show_itemlist=True),
+    )
     win.resize(800, 600)
     return win
 
+
 def test():
     """Test"""
     # -- Create QApplication
     import guidata
+
     _app = guidata.qapplication()
     # --
     filename = osp.join(osp.dirname(__file__), "brain.png")
@@ -37,5 +43,6 @@ def test():
     plot.add_item(image2, z=1)
     win.exec_()
 
+
 if __name__ == "__main__":
     test()
