@@ -7,11 +7,12 @@
 
 """Flip/rotate test"""
 
-SHOW = True # Show test in GUI-based test launcher
+SHOW = True  # Show test in GUI-based test launcher
 
 from guiqwt.widgets.fliprotate import FlipRotateDialog, FlipRotateWidget
 from guiqwt.tests.rotatecrop import imshow, create_test_data
 
+
 def widget_test(fname, qapp):
     """Test the rotate/crop widget"""
     array0, item = create_test_data(fname)
@@ -21,6 +22,7 @@ def widget_test(fname, qapp):
     widget.show()
     qapp.exec_()
 
+
 def dialog_test(fname, interactive=True):
     """Test the rotate/crop dialog"""
     array0, item = create_test_data(fname)
@@ -32,10 +34,10 @@ def dialog_test(fname, interactive=True):
         imshow(array1, title="array1")
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     from guidata import qapplication
+
     qapp = qapplication()  # analysis:ignore
-    
+
     widget_test("brain.png", qapp)
     dialog_test(fname="brain.png", interactive=True)
-    
\ No newline at end of file
