@@ -10,8 +10,6 @@ SIFT, the Signal and Image Filtering Tool
 Simple signal and image processing application based on guiqwt and guidata
 """
 
-from __future__ import unicode_literals, print_function
-
 SHOW = True  # Show test in GUI-based test launcher
 
 from qtpy.QtWidgets import (
@@ -26,7 +24,7 @@ from qtpy.QtWidgets import (
     QMenu,
     QApplication,
 )
-from qtpy.QtGui import QFont, QCursor
+from qtpy.QtGui import QCursor
 from qtpy.QtCore import Qt, __version__, Signal
 from qtpy import PYQT5
 from qtpy.compat import getopenfilenames, getsavefilename
@@ -49,10 +47,15 @@ from guidata.dataset.dataitems import (
 )
 from guidata.dataset.qtwidgets import DataSetEditGroupBox
 from guidata.configtools import get_icon
-from guidata.qthelpers import create_action, add_actions, get_std_icon
+from guidata.qthelpers import (
+    create_action,
+    add_actions,
+    get_std_icon,
+    win32_fix_title_bar_background,
+)
+from guidata.widgets.console import DockableConsole
 from guidata.qtwidgets import DockableWidget, DockableWidgetMixin
 from guidata.utils import update_dataset
-from qtpy.py3compat import to_text_string
 
 from guiqwt.config import _
 from guiqwt.plot import CurveWidget, ImageWidget
@@ -69,7 +72,7 @@ VERSION = "0.2.8"
 def normalize(yin, parameter="maximum"):
     """
     Normalize input array *yin* with respect to parameter *parameter*
-    
+
     Support values for *parameter*:
         'maximum' (default), 'amplitude', 'sum', 'energy'
     """
@@ -220,7 +223,11 @@ class ImageParamNew(DataSet):
     )
     type = ChoiceItem(
         _("Type"),
-        (("zeros", _("zeros")), ("empty", _("empty")), ("rand", _("random")),),
+        (
+            ("zeros", _("zeros")),
+            ("empty", _("empty")),
+            ("rand", _("random")),
+        ),
     )
 
 
@@ -822,7 +829,7 @@ class SignalFT(ObjectFT):
         sys.stdin, sys.stdout, sys.stderr = saved_in, saved_out, saved_err
         filenames = list(filenames)
         for filename in filenames:
-            filename = to_text_string(filename)
+            filename = str(filename)
             os.chdir(osp.dirname(filename))
             signal = SignalParam()
             signal.title = filename
@@ -876,7 +883,7 @@ class SignalFT(ObjectFT):
             )
             if not filename:
                 return
-            filename = to_text_string(filename)
+            filename = str(filename)
             os.chdir(osp.dirname(filename))
             obj = self.objects[row]
             try:
@@ -1364,7 +1371,7 @@ class DockablePlotWidget(DockableWidget):
         return self.plotwidget.plot
 
     def setup(self):
-        title = to_text_string(self.toolbar.windowTitle())
+        title = str(self.toolbar.windowTitle())
         self.plotwidget.add_toolbar(self.toolbar, title)
         if isinstance(self.plotwidget, ImageWidget):
             self.plotwidget.register_all_image_tools()
@@ -1382,59 +1389,8 @@ class DockableTabWidget(QTabWidget, DockableWidgetMixin):
     LOCATION = Qt.LeftDockWidgetArea
 
     def __init__(self, parent):
-        if PYQT5:
-            super(DockableTabWidget, self).__init__(parent, parent=parent)
-        else:
-            QTabWidget.__init__(self, parent)
-            DockableWidgetMixin.__init__(self, parent)
-
-
-try:
-    try:
-        # Spyder 2
-        from spyderlib.widgets.internalshell import InternalShell
-    except ImportError:
-        # Spyder 3
-        from spyder.widgets.internalshell import InternalShell
-
-    class DockableConsole(InternalShell, DockableWidgetMixin):
-        LOCATION = Qt.BottomDockWidgetArea
-
-        def __init__(self, parent, namespace, message, commands=[]):
-            InternalShell.__init__(
-                self,
-                parent=parent,
-                namespace=namespace,
-                message=message,
-                commands=commands,
-                multithreaded=True,
-            )
-            DockableWidgetMixin.__init__(self, parent)
-            self.setup()
-
-        def setup(self):
-            font = QFont("Courier new")
-            font.setPointSize(10)
-            self.set_font(font)
-            self.set_codecompletion_auto(True)
-            self.set_calltips(True)
-            try:
-                # Spyder 2
-                self.setup_completion(size=(300, 180), font=font)
-            except TypeError:
-                pass
-            try:
-                self.traceback_available.connect(self.show_console)
-            except AttributeError:
-                pass
-
-        def show_console(self):
-            self.dockwidget.raise_()
-            self.dockwidget.show()
-
-
-except ImportError:
-    DockableConsole = None
+        QTabWidget.__init__(self, parent)
+        DockableWidgetMixin.__init__(self)
 
 
 class SiftProxy(object):
@@ -1447,6 +1403,7 @@ class SiftProxy(object):
 class MainWindow(QMainWindow):
     def __init__(self):
         QMainWindow.__init__(self)
+        win32_fix_title_bar_background(self)
 
         self.setWindowIcon(get_icon("sift.svg"))
         self.setWindowTitle(APP_NAME)
@@ -1519,37 +1476,33 @@ class MainWindow(QMainWindow):
         self.proc_menu = self.menuBar().addMenu(_("Processing"))
         self.proc_menu.aboutToShow.connect(self.update_proc_menu)
 
-        # Eventually add an internal console (requires 'spyderlib')
+        # Add an internal console
         self.sift_proxy = SiftProxy(self)
-        if DockableConsole is None:
-            self.console = None
-        else:
-            import time, scipy.signal as sps, scipy.ndimage as spi
+        import time, scipy.signal as sps, scipy.ndimage as spi
 
-            ns = {
-                "sift": self.sift_proxy,
-                "np": np,
-                "sps": sps,
-                "spi": spi,
-                "os": os,
-                "sys": sys,
-                "osp": osp,
-                "time": time,
-            }
-            msg = (
-                "Example: sift.s[0] returns signal object #0\n"
-                "Modules imported at startup: "
-                "os, sys, os.path as osp, time, "
-                "numpy as np, scipy.signal as sps, scipy.ndimage as spi"
-            )
-            self.console = DockableConsole(self, namespace=ns, message=msg)
-            self.add_dockwidget(self.console, _("Console"))
-            try:
-                self.console.interpreter.widget_proxy.sig_new_prompt.connect(
-                    lambda txt: self.refresh_lists()
-                )
-            except AttributeError:
-                print("sift: spyderlib is outdated", file=sys.stderr)
+        ns = {
+            "sift": self.sift_proxy,
+            "np": np,
+            "sps": sps,
+            "spi": spi,
+            "os": os,
+            "sys": sys,
+            "osp": osp,
+            "time": time,
+        }
+        msg = (
+            "Example: sift.s[0] returns signal object #0\n"
+            "Modules imported at startup: "
+            "os, sys, os.path as osp, time, "
+            "numpy as np, scipy.signal as sps, scipy.ndimage as spi"
+        )
+        self.console = DockableConsole(
+            self, namespace=ns, message=msg, multithreaded=False
+        )
+        self.add_dockwidget(self.console, _("Console"))
+        self.console.interpreter.widget_proxy.sig_new_prompt.connect(
+            lambda txt: self.refresh_lists()
+        )
 
         # View menu
         self.view_menu = view_menu = self.createPopupMenu()
@@ -1636,8 +1589,10 @@ class MainWindow(QMainWindow):
         )
 
     def closeEvent(self, event):
-        if self.console is not None:
-            self.console.exit_interpreter()
+        # TODO: Find out why this method is never called when closing main window
+        # with PySide6 (and potentially PyQt6 -- not tested), and then reenable the
+        # console 'multithreaded' option
+        self.console.close()
         event.accept()
 
 
@@ -1647,7 +1602,10 @@ def run():
     app = qapplication()
     window = MainWindow()
     window.show()
-    app.exec_()
+    try:
+        app.exec()
+    except AttributeError:
+        app.exec_()
 
 
 if __name__ == "__main__":
