@@ -7,7 +7,7 @@
 
 """Simple dialog box based on guiqwt and guidata"""
 
-SHOW = True # Show test in GUI-based test launcher
+SHOW = True  # Show test in GUI-based test launcher
 
 import scipy.ndimage
 
@@ -30,28 +30,35 @@ class ImageParam(DataSet):
 
 
 class FilterParam(DataSet):
-    name = ChoiceItem(_("Filter algorithm"),
-                      (
-                       ("gaussian_filter", _("gaussian filter")),
-                       ("uniform_filter", _("uniform filter")),
-                       ("minimum_filter", _("minimum filter")),
-                       ("median_filter", _("median filter")),
-                       ("maximum_filter", _("maximum filter")),
-                       ))
+    name = ChoiceItem(
+        _("Filter algorithm"),
+        (
+            ("gaussian_filter", _("gaussian filter")),
+            ("uniform_filter", _("uniform filter")),
+            ("minimum_filter", _("minimum filter")),
+            ("median_filter", _("median filter")),
+            ("maximum_filter", _("maximum filter")),
+        ),
+    )
     size = IntItem(_("Size or sigma"), min=1, default=5)
-    
+
+
 class ExampleDialog(ImageDialog):
-    def __init__(self, wintitle=_("Example dialog box"),
-                 icon="guidata.svg", options=dict(show_contrast=True),
-                 edit=False):
+    def __init__(
+        self,
+        wintitle=_("Example dialog box"),
+        icon="guidata.svg",
+        options=dict(show_contrast=True),
+        edit=False,
+    ):
         self.filter_gbox = None
         self.data = None
         self.item = None
-        super(ExampleDialog, self).__init__(wintitle=wintitle, icon=icon,
-                                            toolbar=True, edit=edit,
-                                            options=options)        
+        super(ExampleDialog, self).__init__(
+            wintitle=wintitle, icon=icon, toolbar=True, edit=edit, options=options
+        )
         self.resize(600, 600)
-        
+
     def register_tools(self):
         opentool = self.add_tool(OpenImageTool)
         opentool.SIG_OPEN_FILE.connect(self.open_image)
@@ -59,17 +66,16 @@ class ExampleDialog(ImageDialog):
         self.activate_default_tool()
 
     def create_plot(self, options):
-        self.filter_gbox = DataSetEditGroupBox(_("Filter parameters"),
-                                               FilterParam)
+        self.filter_gbox = DataSetEditGroupBox(_("Filter parameters"), FilterParam)
         self.filter_gbox.setEnabled(False)
         self.filter_gbox.SIG_APPLY_BUTTON_CLICKED.connect(self.apply_filter)
         self.plot_layout.addWidget(self.filter_gbox, 0, 0)
         self.param_gbox = DataSetShowGroupBox(_("Image parameters"), ImageParam)
         self.plot_layout.addWidget(self.param_gbox, 0, 1)
-        
+
         options = dict(title=_("Image title"), zlabel=_("z-axis scale label"))
         ImageDialog.create_plot(self, options, 1, 0, 1, 0)
-        
+
     def open_image(self, filename):
         """Opening image *filename*"""
         self.data = io.imread(filename, to_grayscale=True)
@@ -80,7 +86,7 @@ class ExampleDialog(ImageDialog):
         update_dataset(self.param_gbox.dataset, param)
         self.param_gbox.get()
         self.filter_gbox.setEnabled(True)
-        
+
     def show_data(self, data):
         plot = self.get_plot()
         if self.item is not None:
@@ -90,15 +96,17 @@ class ExampleDialog(ImageDialog):
             plot.add_item(self.item, z=0)
         plot.set_active_item(self.item)
         plot.replot()
-        
+
     def apply_filter(self):
         param = self.filter_gbox.dataset
         filterfunc = getattr(scipy.ndimage, param.name)
         data = filterfunc(self.data, param.size)
         self.show_data(data)
 
+
 if __name__ == "__main__":
     from guidata import qapplication
+
     _app = qapplication()
     dlg = ExampleDialog()
-    dlg.exec_() # No need to call app.exec_: a dialog box has its own event loop
+    dlg.exec_()  # No need to call app.exec_: a dialog box has its own event loop
