@@ -58,34 +58,34 @@ The `tools` module provides a collection of `plot tools` :
     * :py:class:`guiqwt.tools.ItemCenterTool`
     * :py:class:`guiqwt.tools.DeleteItemTool`
 
-A `plot tool` is an object providing various features to a plotting widget 
-(:py:class:`guiqwt.curve.CurvePlot` or :py:class:`guiqwt.image.ImagePlot`): 
+A `plot tool` is an object providing various features to a plotting widget
+(:py:class:`guiqwt.curve.CurvePlot` or :py:class:`guiqwt.image.ImagePlot`):
 buttons, menus, selection tools, image I/O tools, etc.
-To make it work, a tool has to be registered to the plotting widget's manager, 
-i.e. an instance of the :py:class:`guiqwt.plot.PlotManager` class (see 
+To make it work, a tool has to be registered to the plotting widget's manager,
+i.e. an instance of the :py:class:`guiqwt.plot.PlotManager` class (see
 the :py:mod:`guiqwt.plot` module for more details on the procedure).
 
-The `CurvePlot` and `ImagePlot` widgets do not provide any `PlotManager`: the 
-manager has to be created separately. On the contrary, the ready-to-use widgets 
+The `CurvePlot` and `ImagePlot` widgets do not provide any `PlotManager`: the
+manager has to be created separately. On the contrary, the ready-to-use widgets
 :py:class:`guiqwt.plot.CurveWidget` and :py:class:`guiqwt.plot.ImageWidget`
 are higher-level plotting widgets with integrated manager, tools and panels.
 
 .. seealso::
-        
+
     Module :py:mod:`guiqwt.plot`
-        Module providing ready-to-use curve and image plotting widgets and 
+        Module providing ready-to-use curve and image plotting widgets and
         dialog boxes
-    
+
     Module :py:mod:`guiqwt.curve`
         Module providing curve-related plot items and plotting widgets
-        
+
     Module :py:mod:`guiqwt.image`
         Module providing image-related plot items and plotting widgets
 
 Example
 ~~~~~~~
 
-The following example add all the existing tools to an `ImageWidget` object 
+The following example add all the existing tools to an `ImageWidget` object
 for testing purpose:
 
 .. literalinclude:: /../guiqwt/tests/image_plot_tools.py
@@ -238,17 +238,6 @@ Reference
 # TODO: z(long-terme) à partir d'une sélection rectangulaire sur une image
 #      afficher un ArrayEditor montrant les valeurs de la zone sélectionnée
 
-from __future__ import unicode_literals
-
-try:
-    # PyQt4 4.3.3 on Windows (static DLLs) with py2exe installed:
-    # -> pythoncom must be imported first, otherwise py2exe's boot_com_servers
-    #    will raise an exception ("Unable to load DLL [...]") when calling any
-    #    of the QFileDialog static methods (getOpenFileName, ...)
-    import pythoncom
-except ImportError:
-    pass
-
 import sys
 import numpy as np
 import weakref
@@ -267,10 +256,10 @@ from qtpy.QtWidgets import (
 from qtpy.compat import getsavefilename, getopenfilename
 
 from guidata.qthelpers import get_std_icon, add_actions, add_separator
+from guidata.widgets.objecteditor import oedit
 from guidata.configtools import get_icon
 from guidata.dataset.datatypes import DataSet
 from guidata.dataset.dataitems import BoolItem, FloatItem
-from qtpy.py3compat import is_text_string, to_text_string
 
 # Local imports
 from guiqwt.config import _
@@ -311,6 +300,7 @@ from guiqwt.interfaces import (
     ICurveItemType,
 )
 from guiqwt.panels import ID_XCS, ID_YCS, ID_OCS, ID_ITEMLIST, ID_CONTRAST
+from guiqwt.interfaces import IImageItemType
 
 
 class DefaultToolbarID:
@@ -329,8 +319,6 @@ class GuiTool(QObject):
         self.plots = set()
         self.action = self.create_action(manager)
         self.menu = self.create_action_menu(manager)
-        if self.menu is not None:
-            self.action.setMenu(self.menu)
         if toolbar_id is DefaultToolbarID:
             toolbar = manager.get_default_toolbar()
         else:
@@ -347,6 +335,7 @@ class GuiTool(QObject):
         toolbar.addAction(self.action)
         if self.menu is not None:
             widget = toolbar.widgetForAction(self.action)
+            widget.setMenu(self.menu)
             widget.setPopupMode(QToolButton.InstantPopup)
 
     def create_action_menu(self, manager):
@@ -375,8 +364,8 @@ class GuiTool(QObject):
     def update_status(self, plot):
         """called by to allow derived
         classes to update the states of actions based on the currently
-        active BasePlot 
-        
+        active BasePlot
+
         can also be called after an action modifying the BasePlot
         (e.g. in order to update action states when an item is deselected)
         """
@@ -676,7 +665,12 @@ class MultiLineTool(InteractiveTool):
         )
         filter.add_event(
             start_state,
-            KeyEventMatch((Qt.Key_Backspace, Qt.Key_Escape,)),
+            KeyEventMatch(
+                (
+                    Qt.Key_Backspace,
+                    Qt.Key_Escape,
+                )
+            ),
             self.cancel_point,
             start_state,
         )
@@ -1227,6 +1221,11 @@ class CrossSectionTool(RectangularShapeTool):
         super(CrossSectionTool, self).handle_final_shape(shape)
         self.register_shape(shape, final=True)
 
+    def update_status(self, plot):
+        if update_image_tool_status(self, plot):
+            item = plot.get_selected_items(item_type=IImageItemType)
+            self.action.setEnabled(len(item) > 0)
+
 
 class AverageCrossSectionTool(CrossSectionTool):
     SWITCH_TO_DEFAULT_TOOL = True
@@ -1466,7 +1465,7 @@ class CommandTool(GuiTool):
         self, manager, title, icon=None, tip=None, toolbar_id=DefaultToolbarID
     ):
         self.title = title
-        if icon and is_text_string(icon):
+        if icon and isinstance(icon, str):
             self.icon = get_icon(icon)
         else:
             self.icon = icon
@@ -1484,7 +1483,11 @@ class CommandTool(GuiTool):
         )
 
     def setup_context_menu(self, menu, plot):
-        menu.addAction(self.action)
+        if self.menu is not None:
+            self.menu.setTitle(self.action.text())
+            menu.addMenu(self.menu)
+        else:
+            menu.addAction(self.action)
 
     def activate(self, checked=True):
         plot = self.get_active_plot()
@@ -1746,7 +1749,6 @@ class SaveAsTool(CommandTool):
         # --> until this bug is fixed internally, disabling PDF output format
         #     when plot has image items.
         formats = "%s (*.png)" % _("PNG image")
-        from guiqwt.interfaces import IImageItemType
 
         for item in plot.get_items():
             if IImageItemType in item.types():
@@ -1931,7 +1933,7 @@ class SnapshotTool(RectangularActionTool):
 
 class RotateCropTool(CommandTool):
     """Rotate & Crop tool
-    
+
     See :py:class:`guiqwt.rotatecrop.RotateCropDialog` dialog."""
 
     def __init__(self, manager, toolbar_id=DefaultToolbarID, options=None):
@@ -2005,7 +2007,7 @@ class OpenFileTool(CommandTool):
         sys.stdout = None
         filename, _f = getopenfilename(plot, _("Open"), self.directory, self.formats)
         sys.stdin, sys.stdout, sys.stderr = saved_in, saved_out, saved_err
-        filename = to_text_string(filename)
+        filename = str(filename)
         if filename:
             self.directory = osp.dirname(filename)
         return filename
@@ -2237,7 +2239,7 @@ def export_curve_data(item):
     fname, _f = getsavefilename(plot, title, "", _("Text file") + " (*.txt)")
     if fname:
         try:
-            np.savetxt(to_text_string(fname), data, delimiter=",")
+            np.savetxt(str(fname), data, delimiter=",")
         except RuntimeError as error:
             QMessageBox.critical(
                 plot,
@@ -2246,7 +2248,7 @@ def export_curve_data(item):
                 + "<br><br>"
                 + _("Error message:")
                 + "<br>"
-                + to_text_string(error),
+                + str(error),
             )
 
 
@@ -2284,12 +2286,6 @@ def edit_curve_data(item):
     else:
         x, y = item_data
         data = np.array([x, y]).T
-    try:
-        # Spyder 2
-        from spyderlib.widgets.objecteditor import oedit
-    except ImportError:
-        # Spyder 3
-        from spyder.widgets.variableexplorer.objecteditor import oedit
     if oedit(data) is not None:
         if data.shape[1] > 2:
             if data.shape[1] == 3:
@@ -2306,26 +2302,18 @@ def edit_curve_data(item):
             item.set_data(x, y)
 
 
-def edit_image_data(item):
-    """Edit image item data to file"""
-    try:
-        # Spyder 2
-        from spyderlib.widgets.objecteditor import oedit
-    except ImportError:
-        # Spyder 3
-        from spyder.widgets.variableexplorer.objecteditor import oedit
-    oedit(item.data)
-
-
 class EditItemDataTool(ItemManipulationBaseTool):
-    """Edit item data (requires `spyderlib`)"""
+    """Edit item data"""
 
     TITLE = _("Edit data...")
     ICON = "arredit.png"
 
     def __init__(self, manager, toolbar_id=None):
         super(EditItemDataTool, self).__init__(
-            manager, toolbar_id, curve_func=edit_curve_data, image_func=edit_image_data
+            manager,
+            toolbar_id,
+            curve_func=edit_curve_data,
+            image_func=lambda item: oedit(item.data),
         )
 
 
@@ -2400,7 +2388,7 @@ class DeleteItemTool(CommandTool):
 class FilterTool(CommandTool):
     def __init__(self, manager, filter, toolbar_id=None):
         super(FilterTool, self).__init__(
-            manager, to_text_string(filter.name), toolbar_id=toolbar_id
+            manager, str(filter.name), toolbar_id=toolbar_id
         )
         self.filter = filter
 
@@ -2556,7 +2544,6 @@ class ImageMaskTool(CommandTool):
                 removeshapes_a,
             ),
         )
-        self.action.setMenu(menu)
         return menu
 
     def update_status(self, plot):
